@@ -16,10 +16,13 @@ COOKIE_MAX_AGE = getattr(settings, 'COOKIE_MAX_AGE', 31536000) # 1 year
 VISITOR_IGNORE_IP_LIST = getattr(settings, 'VISITOR_IGNORE_IP_LIST', ('127.0.0.1',))
 
 def create_uuid(*parts):
+    """ create a uuid """
     name = '-'.join([str(counter())] + [str(time.time())] + [str(p) for p in parts])
     return str(uuid.uuid5(uuid.NAMESPACE_URL, name))
 
 def ip_address_from_request(request):
+    """ get the ip address from the request added special logic for lots
+    of different conditions, proxies, etc. """
     meta = request.META
 
   # figure out the IP
@@ -46,7 +49,11 @@ def ip_address_from_request(request):
 
     return ip_address
 
-def create_visitor(ip_address,session_key):
+def get_visitor(visitor_key):
+    """ get visitor by their visitor key"""
+    return Visitor.objects.find_visitor(visitor_key)
+
+def create_visitor(ip_address, session_key):
     """ Create the visitor given an ip_address """
     visitor = Visitor()
     visitor.generate_key(ip_address)
@@ -55,9 +62,9 @@ def create_visitor(ip_address,session_key):
     visitor.save()
     return visitor
 
-def update_visitor(visitor_key,session_key=None):
+def update_visitor(visitor_key, session_key=None):
     """ update the visitor using the visitor key """
-    visitor = Visitor.objects.find_visitor(visitor_key)
+    visitor = get_visitor(visitor_key)
     if visitor:
         visitor.mark_visit()
         if session_key:
@@ -78,6 +85,7 @@ def get_visitor_from_request(request):
         return get_visitor(request.COOKIES[constants.COOKIE_VISITOR_KEY])
     else:
         return None
+
 def set_visitor_cookie(response, visitor):
     """ set the visitor cookie using the visitor object """
     if response and visitor and visitor.visitor_key:
@@ -105,5 +113,3 @@ def delete_visitor_cookie(response):
             constants.COOKIE_VISITOR_KEY,
             domain=COOKIE_DOMAIN
         )
-
-
